@@ -14,8 +14,8 @@ class AuthenticatedSessionAPI(APIEndpoint):
             :obj:`dict`: The authenticated session information.
 
         Examples:
-            >>> zpa.session.create(client_id='Eh3UzT7E2RXkjCkYQMbVF9jWDJNY4geM6bMp6NXxxCkzjjf77B7YpYMMuGhb==',
-            ...    client_secret='fvWHWSC(Z%]7AbmVH%qR%Yt;iUG89Z')
+            >>> zpa.session.create(client_id='xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx==',
+            ...    client_secret='yyyyyyyyyyyyyyyyyyyyyyyyyyyyyy')
 
         """
 
@@ -24,19 +24,4 @@ class AuthenticatedSessionAPI(APIEndpoint):
         headers = {
             "Content-Type": "application/x-www-form-urlencoded",
         }
-        return self._post(
-            "https://config.private.zscaler.com/signin", headers=headers, data=payload
-        ).access_token
-
-    def delete(self):
-        """
-        Deletes the ZPA authentication session.
-
-        Returns:
-            :obj:`str`: The status code of the operation.
-
-        Examples:
-            >>> zpa.session.delete()
-
-        """
-        return self._post("https://config.private.zscaler.com/signout")
+        return self._post("https://config.private.zscaler.com/signin", headers=headers, data=payload).access_token
